@@ -44,7 +44,7 @@ def read_parquet_uri(uri: str, *, df_description: str = "dataframe", **kwargs: A
     :param kwargs: These are forwarded to `pd.read_parquet`.
     """
     timer = Timer()
-    read_description = f"{df_description} from {uri} using smart-open"
+    read_description = f"{df_description} from {uri}"
     log.info(f"Reading {read_description}.")
     try:
         with smart_open.open(uri, "rb") as input_file:
@@ -65,7 +65,7 @@ def write_parquet_uri(df: pd.DataFrame, uri: str, *, df_description: str = "data
     :param kwargs: These are forwarded to `df.to_parquet`.
     """
     timer = Timer()
-    write_description = f"{df_description} to {uri} using smart-open"
+    write_description = f"{df_description} to {uri}"
     log.info(f"Writing {write_description}.")
     try:
         with smart_open.open(uri, "wb") as output_file:
